@@ -73,6 +73,7 @@ class StampTask(Task):
         self.invalidateCache()
         if self.complete():
             return
-        super().run()
+        rtn = yield from super().run()
         with self.output().fpWrite() as fpw:
             fpw.write(self.getCodeHash())
+        return rtn
